/*****************************************************************************

        Token.cpp
        Author: Laurent de Soras, 2009

--- Legal stuff ---

This program is free software. It comes without any warranty, to
the extent permitted by applicable law. You can redistribute it
and/or modify it under the terms of the Do What The Fuck You Want
To Public License, Version 2, as published by Sam Hocevar. See
http://sam.zoy.org/wtfpl/COPYING for more details.

*Tab=3***********************************************************************/



#if defined (_MSC_VER)
	#pragma warning (1 : 4130 4223 4705 4706)
	#pragma warning (4 : 4355 4786 4800)
#endif



/*\\\ INCLUDE FILES \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\*/

#include	"Token.h"

#include	<cassert>
#include	<cctype>



/*\\\ PUBLIC \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\*/



void	Token::process (std::list <std::string> &token_list, const std::string &content, char delimiter, long max_nbr_fields)
{
	assert (&token_list != 0);
	assert (&content != 0);
	assert (max_nbr_fields > 0);

	token_list.clear ();

	std::string::size_type	pos = 0;
	long				nbr_lines = 0;
	bool				cont_flag = true;
	do
	{
		const std::string::size_type	old_pos = pos;
		pos = content.find (delimiter, old_pos);
		if (pos == std::string::npos || nbr_lines >= max_nbr_fields - 1)
		{
			pos = content.length ();
			cont_flag = false;
		}

		const std::string	sub = content.substr (old_pos, pos - old_pos);
		token_list.push_back (sub);
		++ nbr_lines;

		++ pos;	// Skips delimiter
	}
	while (cont_flag);
}



std::string	Token::remove_white (const std::string &token, bool left_flag, bool right_flag)
{
	assert (&token != 0);

	long				tok_beg = 0;
	long				tok_end = long (token.length ());

	if (left_flag)
	{
		while (tok_beg < tok_end && isspace (token [tok_beg]))
		{
			++ tok_beg;
		}
	}

	if (right_flag)
	{
		while (tok_beg < tok_end && isspace (token [tok_end - 1]))
		{
			-- tok_end;
		}
	}

	return (token.substr (tok_beg, tok_end - tok_beg));
}



/*\\\ PROTECTED \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\*/



/*\\\ PRIVATE \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\*/



/*\\\ EOF \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\*/
