
@rem usage: encode-part <avsinput> <beg> <end> <timecodes> <qpfile> <zones> <bits> <options>
@rem                        1        2     3        4         5        6      7        8+
@rem avsintput: not trimmed, 16-bit interleaved if target is 10 bits. Trimming is done in this script.
@rem beg, end: half-open interval to encode.
@rem timecodes, qpfile and zones: specify "" when there is no file to use. The zone file has a specific format, see the trimx264opt documentation.
@rem bits: output bits. 8 or 10.
@rem options: x264 parameters, with everything, including output and stream-format information (for piping), but without zones, qpfile, timecodes, input and --stitchable.
@rem
@rem Requires the following environment variables to be defined (in setpaths.bat):
@rem %trimx264opt%
@rem %avs2pipemod%
@rem %x264%
@rem %x2640864%
@rem %x26410%
@rem %x2641064%

@setlocal ENABLEDELAYEDEXPANSION

@call setpaths

@if %~3 equ 0   goto rangeok
@if %~3 gtr %~2 goto rangeok
@echo *** Error: invalid half-open range ^[%~2, %~3^). ***
@goto :eof
:rangeok

@set locx26432=%x264%
@set locx26464=%x2640864%
@if "%~7" equ "10" (
	@set locx26432=!x26410!
	@set locx26464=!x2641064!
) else if "%~7" neq "8" (
	@echo *** Error: specify "8" or "10" bits as 7th argument. ***
	@goto :eof
)

@set xopt=
@set pipemode=0
:xoptloop
	@if "%~8" equ ""             goto xoptdone
	@if "%~8" equ "--demuxer"    set pipemode=1
	@if "%~8" equ "--qpfile"     goto xopterr
	@if "%~8" equ "--tcfile-in"  goto xopterr
	@if "%~8" equ "--zones"      goto xopterr
	@if "%~8" equ "--stitchable" goto xopterr
	@set xopt=!xopt! "%~8"
	@shift /8
@goto xoptloop
:xopterr
@echo *** Error: don't use %~8 in the x264 parameters. ***
@goto :eof
:xoptdone

@set trimopttc=
@set x264opttc=
@set filetcout=
@if "%~4" neq "" (
	@set filetcout=%~dpn4-%~2-%~3.txt
	@set trimopttc=--tcin "%~4" --tcout "!filetcout!"
	@set x264opttc=--tcfile-in "!filetcout!"
)

@set trimoptqp=
@set x264optqp=
@set fileqpout=
@if "%~5" neq "" (
	@set fileqpout=%~dpn5-%~2-%~3.txt
	@set trimoptqp=--qpin "%~5" --qpout "!fileqpout!"
	@set x264optqp=--qpfile "!fileqpout!"
)

@set trimoptzn=
@set x264optzn=
@set fileznout=
@if "%~6" neq "" (
	@set fileznout=%~dpn6-%~2-%~3.bat
	@set trimoptzn=--zonein "%~6" --zoneout "!fileznout!"
)

call "%trimx264opt%" %trimopttc% %trimoptqp% %trimoptzn% "%~2" "%~3"
@if "%~6" neq "" (
	@call "!fileznout!"
	@if "!x264zones!" NEQ "" set x264optzn=--zones !x264zones!
)

@set tmpavsfile=%~dpn1-%~2-%~3.avs
@echo encodepart_beg = %~2                     > "%tmpavsfile%"
@echo encodepart_end = %~3                    >> "%tmpavsfile%"
@echo Import ("%~dpf1")                       >> "%tmpavsfile%"
@echo Trim (%~2, (%~3 == 0) ? 0 : %~2 - %~3 ) >> "%tmpavsfile%"

@if "%pipemode%" neq "0" (
	call "!avs2pipemod!" -rawvideo "!tmpavsfile!" | "!locx26464!" --stitchable !x264opttc! !x264optqp! !x264optzn! !xopt! -
) else (
	call "!locx26432!" --stitchable !x264opttc! !x264optqp! !x264optzn! !xopt! "!tmpavsfile!"
)

@del %tmpavsfile%
@if "%~4" neq "" del %filetcout%
@if "%~5" neq "" del %fileqpout%
@if "%~6" neq "" del %fileznout%
